==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/panel/lxqt-panel_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>أضف ملحقات</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>ابحث:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>أضف ودجة</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>أغلق</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(يمكن تشغيل سيرورة واحدة من هذه الودجة فقط)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>اضبط اللوحة</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>اللوحة</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>الودجات</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>اضبط اللوحة</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>المقاس</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;تضبط القيم السّالبة طولَ اللوحة ليكون أقلّ من مساحة الشّاشة المتوفّرة بالعدد المحدّد.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;مثلًا إن كان &quot;الطّول&quot; هو -100بكسل، وحجم الشّاشة هو 1000بكسل، فسيكون طول اللوحة الحقيقيّ 900 بكسل.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>المقاس:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>الطّول:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>بكسل</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>مقاس الأيقونات:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>عدد الصّفوف:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>المحاذاة والمكان</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>Zero means no animation</source>
        <translation>يعني الصّفر لا تأثير حركة</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="227"/>
        <source> ms</source>
        <translation> م‌ث</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="240"/>
        <source>Position:</source>
        <translation>المكان:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="253"/>
        <source>Animation duration:</source>
        <translation>مدّة تأثير الحركة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="260"/>
        <source>Alignment:</source>
        <translation>المحاذاة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="284"/>
        <location filename="../../../config/configpanelwidget.cpp" line="195"/>
        <source>Left</source>
        <translation>اليسار</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="289"/>
        <location filename="../../../config/configpanelwidget.cpp" line="196"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Center</source>
        <translation>الوسط</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="294"/>
        <location filename="../../../config/configpanelwidget.cpp" line="197"/>
        <source>Right</source>
        <translation>اليمين</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="214"/>
        <source>Auto-hide</source>
        <translation>أخفِ آليًّا</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source>Custom styling</source>
        <translation>نمط مخصّص</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="335"/>
        <source>Font color:</source>
        <translation>لون الخطّ:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="375"/>
        <source>Background color:</source>
        <translation>لون الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="414"/>
        <source>Background opacity:</source>
        <translation>شفافيّة الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="446"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;التّراكب مطلوب لشفافيّة اللوحة.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="474"/>
        <source>Background image:</source>
        <translation>صورة الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="161"/>
        <source>Top of desktop</source>
        <translation>أعلى سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="162"/>
        <source>Left of desktop</source>
        <translation>يسار سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="163"/>
        <source>Right of desktop</source>
        <translation>يمين سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="164"/>
        <source>Bottom of desktop</source>
        <translation>أدنى سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="173"/>
        <source>Top of desktop %1</source>
        <translation>أعلى سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="174"/>
        <source>Left of desktop %1</source>
        <translation>يسار سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="175"/>
        <source>Right of desktop %1</source>
        <translation>يمين سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="176"/>
        <source>Bottom of desktop %1</source>
        <translation>أدنى سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="201"/>
        <source>Top</source>
        <translation>الأعلى</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <source>Bottom</source>
        <translation>الأسفل</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="360"/>
        <location filename="../../../config/configpanelwidget.cpp" line="376"/>
        <source>Pick color</source>
        <translation>اختر لونًا</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="394"/>
        <source>Pick image</source>
        <translation>اختر صورة</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="394"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>صور (‎*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>اضبط اللوحات</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>لاحظ: التّعديلات على هذه الصّفحة لا عودة فيها.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>انقل لأعلى</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>انقل لأسفل</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>أزل</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>اضبط</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1012"/>
        <location filename="../../../lxqtpanel.cpp" line="1036"/>
        <source>Panel</source>
        <translation>اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1039"/>
        <source>Configure Panel</source>
        <translation>اضبط اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1044"/>
        <source>Manage Widgets</source>
        <translation>أدر الودجات</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1050"/>
        <source>Add New Panel</source>
        <translation>أضف لوحة جديدة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1062"/>
        <source>Lock This Panel</source>
        <translation>اقفل هذه اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1200"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>إزالة اللوحة إجراء لا عودة فيه.
أتريد إزالة هذه اللوحة؟</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1057"/>
        <location filename="../../../lxqtpanel.cpp" line="1199"/>
        <source>Remove Panel</source>
        <translatorcomment>هذه تظهر في مكانين، أمر وعنوان نافذة، اقسمهما!</translatorcomment>
        <translation>أزل اللوحة</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="385"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>اضبط &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="390"/>
        <source>Move &quot;%1&quot;</source>
        <translation>انقل &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="398"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>أزل &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="91"/>
        <source>Use alternate configuration file.</source>
        <translation>استخدم ملفّ ضبط بديل.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="92"/>
        <source>Configuration file</source>
        <translation>ملفّ الضّبط</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/panel/lxqt-panel_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>أضف ملحقات</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>ابحث:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>أضف ودجة</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>أغلق</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(يمكن تشغيل سيرورة واحدة من هذه الودجة فقط)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>اضبط اللوحة</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>اللوحة</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>الودجات</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>اضبط اللوحة</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>المقاس</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;تضبط القيم السّالبة طولَ اللوحة ليكون أقلّ من مساحة الشّاشة المتوفّرة بالعدد المحدّد.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;مثلًا إن كان &quot;الطّول&quot; هو -100بكسل، وحجم الشّاشة هو 1000بكسل، فسيكون طول اللوحة الحقيقيّ 900 بكسل.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>المقاس:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>الطّول:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>بكسل</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>مقاس الأيقونات:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>عدد الصّفوف:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>المحاذاة والمكان</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>يعني الصّفر لا تأثير حركة</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> م‌ث</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>المكان:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>مدّة تأثير الحركة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>المحاذاة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>اليسار</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>الوسط</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>اليمين</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">أخفِ آليًّا</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>نمط مخصّص</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>لون الخطّ:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>لون الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>شفافيّة الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;التّراكب مطلوب لشفافيّة اللوحة.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>صورة الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>أعلى سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>يسار سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>يمين سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>أدنى سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>أعلى سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>يسار سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>يمين سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>أدنى سطح المكتب %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>الأعلى</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>الأسفل</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>اختر لونًا</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>اختر صورة</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>صور (‎*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>اضبط اللوحات</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>لاحظ: التّعديلات على هذه الصّفحة لا عودة فيها.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>انقل لأعلى</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>انقل لأسفل</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>أزل</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>اضبط</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1068"/>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>اضبط اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>أدر الودجات</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>أضف لوحة جديدة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation type="unfinished">أزل اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>اقفل هذه اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1265"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation type="unfinished">أزل اللوحة</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1266"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>إزالة اللوحة إجراء لا عودة فيه.
أتريد إزالة هذه اللوحة؟</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translatorcomment>هذه تظهر في مكانين، أمر وعنوان نافذة، اقسمهما!</translatorcomment>
        <translation type="vanished">أزل اللوحة</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>اضبط &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>انقل &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>أزل &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>استخدم ملفّ ضبط بديل.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>ملفّ الضّبط</translation>
    </message>
</context>
</TS>
